==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnSummaryOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnSummaryOptionsDescription } from "./GridColumnSummaryOptionsDescription";
/**
 * @hidden
 */
export let GridColumnSummaryOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnSummaryOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnSummaryOptionsDescriptionMetadata.a == null) {
                GridColumnSummaryOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnSummaryOptionsDescriptionMetadata.c(GridColumnSummaryOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnSummaryOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnSummaryOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("SummaryCaption", "String");
            a.item("SummaryListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("SummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
            a.item("ActualSummaryListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("ActualSummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
            a.item("ActiveCount", "Number:int");
        }
        static d(a) {
            GridColumnSummaryOptionsDescriptionMetadata.b(a);
            a.ac("GridColumnSummaryOptions", () => new GridColumnSummaryOptionsDescription());
            a.ab("GridColumnSummaryOptions", GridColumnSummaryOptionsDescriptionMetadata.a);
        }
    }
    GridColumnSummaryOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnSummaryOptionsDescriptionMetadata, 'GridColumnSummaryOptionsDescriptionMetadata');
    GridColumnSummaryOptionsDescriptionMetadata.a = null;
    return GridColumnSummaryOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/GridColumnSummaryOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnSummaryOptionsDescription } from "./GridColumnSummaryOptionsDescription";
/**
 * @hidden
 */
export let GridColumnSummaryOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnSummaryOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnSummaryOptionsDescriptionMetadata.a == null) {
                GridColumnSummaryOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnSummaryOptionsDescriptionMetadata.c(GridColumnSummaryOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnSummaryOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnSummaryOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("SummaryCaption", "String");
            a.item("SummaryListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("SummaryListDensity@names", "Auto;Comfortable;Cosy;Compact;Minimal");
            a.item("ActualSummaryListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("ActualSummaryListDensity@names", "Auto;Comfortable;Cosy;Compact;Minimal");
            a.item("ActiveCount", "Number:int");
            a.item("SummaryListTextColor", "Brush");
            a.item("SummaryListBackground", "Brush");
        }
        static d(a) {
            GridColumnSummaryOptionsDescriptionMetadata.b(a);
            a.ae("GridColumnSummaryOptions", () => new GridColumnSummaryOptionsDescription());
            a.ad("GridColumnSummaryOptions", GridColumnSummaryOptionsDescriptionMetadata.a);
        }
    }
    GridColumnSummaryOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnSummaryOptionsDescriptionMetadata, 'GridColumnSummaryOptionsDescriptionMetadata');
    GridColumnSummaryOptionsDescriptionMetadata.a = null;
    return GridColumnSummaryOptionsDescriptionMetadata;
})();
